@@ -4,6 +4,7 @@ import os
 from argparse import Namespace
 from pathlib import Path
 
+import pkg_resources
 import requests
 import yaml
 from owl_client.utils import get_auth, make_request, read_config
@@ -151,8 +152,7 @@ def job_status(args: Namespace) -> None:
 
 
 def job_logs(args: Namespace) -> None:
-    """Get pipeline log
-    """
+    """Get pipeline log"""
     route = "/api/pipeline/log"
     headers = get_auth()
     level = "debug" if args.debug else "info"
@@ -324,3 +324,10 @@ def admin_command(args: Namespace) -> None:
 
     res = make_request(args.api, route, "POST", data=data, auth=True)
     print(res)
+
+
+# List local pipelines -------------------------------------------------------
+def local_pipelines(args: Namespace) -> None:
+    """List local pipelines"""
+    for pipe in pkg_resources.iter_entry_points("owl.pipelines"):
+        print(pipe.dist)
